@@ -287,8 +287,6 @@ signals:
 
     void absoluteGeometryChanged(const QRect &geometry);
 
-    //! pass on signals to children in order to avoid crashes when View is recreated or destroyed
-    void availableScreenRectChangedForViewParts();
     void customPluginsChanged();
 
     //! are used to trigger the Corona relevant signals and in that
